Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1730)

Unified Diff: content/public/common/child_process_host_delegate.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/child_process_host.h ('k') | content/public/common/child_process_host_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/child_process_host_delegate.h
diff --git a/content/public/common/child_process_host_delegate.h b/content/public/common/child_process_host_delegate.h
index 2bf3320d385b54e21068d4b7b935967dd43b4695..62fa80e733d5aa4c0f79385bc58ad828ea5bd925 100644
--- a/content/public/common/child_process_host_delegate.h
+++ b/content/public/common/child_process_host_delegate.h
@@ -11,7 +11,7 @@
#include "content/common/content_export.h"
#include "ipc/ipc_listener.h"
-namespace shell {
+namespace service_manager {
class InterfaceProvider;
}
@@ -36,9 +36,11 @@ class ChildProcessHostDelegate : public IPC::Listener {
// OnProcessLaunched is called or it will be invalid and may crash.
virtual const base::Process& GetProcess() const = 0;
// Returns the shell::InterfaceProvider the process host can use to bind
// interfaces exposed to it from the child.
- CONTENT_EXPORT virtual shell::InterfaceProvider* GetRemoteInterfaces();
+ CONTENT_EXPORT virtual service_manager::InterfaceProvider*
+ GetRemoteInterfaces();
};
}; // namespace content
« no previous file with comments | « content/public/common/child_process_host.h ('k') | content/public/common/child_process_host_delegate.cc » ('j') | no next file with comments »
@@ -36,9 +36,11 @@ class ChildProcessHostDelegate : public IPC::Listener {
// OnProcessLaunched is called or it will be invalid and may crash.
virtual const base::Process& GetProcess() const = 0;
- // Returns the shell::InterfaceProvider the process host can use to bind
+ // Returns the service_manager::InterfaceProvider the process host can use to
+ // bind
// interfaces exposed to it from the child.

Powered by Google App Engine
This is Rietveld 408576698